==> lichenggong-0.2.2.0-py3-none-any.whl: lichenggong/xiugay.py <==
def xiugay(m1919810):
    import os
    import random
    import turtle as t1
    import time as t
    import this
    for i in range(2):
        print('修改中!')
        t.sleep(1)
        print('修改中!!')
        t.sleep(1)
        print('修改中!!!')
        t.sleep(1)
    def tailand(haaasfsa):
        t1.color('red','yellow')
        t1.hideturtle()
        t1.speed(35)
        t1.goto(-100,-10)
        t1.begin_fill()
        for i in range(50):
            t1.forward(200)
            t1.left(170)
        t1.end_fill()
    def LMX(x,y,d):
        t1.penup()
        t1.goto(x, y)
        t1.pendown()
        t1.seth(60)
        for i in range(3):
            t1.fd(d)
            t1.left(120)
        t1.pu()
        t1.goto(x, -y)
        t1.pd()
        t1.seth(-60)
        for i in range(3):
            t1.fd(d)
            t1.right(120)
            t1.hideturtle()
    def yuan(r):
        t1.pu()
        t1.goto(-r*pow(3,0.5)/2, -r/2)
        t1.pd()
        t1.circle(r)
        t1.hideturtle()
    def sixy(x,y,r):
        def txyuan(x,y,r):
            t1.seth(0)
            y = y - r
            t1.pu()
            t1.goto(x, y)
            t1.pd()
            t1.pensize(2)
            t1.circle(r)
            t1.pu()
            t1.goto(x, y+3)
            t1.pd()
            r=r-3
            y=y-r
            t1.circle(r)
        t1.color("#5daed9") 
        txyuan(x,y,r)
        txyuan(-x,y,r)
        txyuan(-x,-y,r)
        txyuan(x,-y,r)
        txyuan(175,0,r)
        txyuan(-175,0,r)
        t1.hideturtle()
    def lbx(x,y):
        t1.penup()
        t1.goto(x, y)
        t1.pendown()
        for i in range(6):
            t1.fd(180)
            t1.left(60)
        t1.hideturtle()
    def yue(x,y,r):
        y=y-r
        t1.penup()
        t1.goto(x,y)
        t1.pendown() 
        t1.circle(r)
        t1.circle(r-10)
        t1.hideturtle()
    def xingzuo(r,c,h):
        t1.penup()
        t1.pencolor("#fdcfad")
        t1.goto(-10,-10)
        t1.seth(-45)
        t1.fd(r)
        t1.pendown()
        xz=['♒','♓','♈','♉','♌','♍','♎','♏','♊','♋','♐','♑']
        for i in range(12):
            t1.write(xz[(i+h)%12],font=("", c, ""))
            t1.penup()
            t1.right(90)
            t1.circle(-r, 30)
            t1.left(90)
            t1.pendown()
        t1.hideturtle()
    def xingdui(r):
        for i in range(1,5):
            te=3
            t1.penup()
            t1.goto(0, 0)
            t1.seth(i * 90)
            t1.pendown()
            t1.right(22.5)
            t1.fd(r)
            if i==1:
                t1.goto(0,3*r-te)
                t1.goto(0,0)
                t1.seth(i * 90 + 22.5)
                t1.fd(r)
                t1.goto(0,3*r-te)
            elif i==2:
                t1.goto(-3*r+te,0)
                t1.goto(0,0)
                t1.seth(i*90+22.5)
                t1.fd(r)
                t1.goto(-3*r+te,0)
            elif i==3:
                t1.goto(0,-3*r+te)
                t1.goto(0,0)
                t1.seth(i*90+22.5)
                t1.fd(r)
                t1.goto(0,-3*r+te)
            else:
                t1.goto(3*r+te,0)
                t1.goto(0,0)
                t1.seth(i*90+22.5)
                t1.fd(r)
                t1.goto(3*r+te,0)
            t1.hideturtle()
        x=pow(((2*r)**2)/2,0.5)-8
        for i in range(1,5):
            t1.pu()
            t1.goto(0, 0)
            t1.seth(i * 90)
            t1.pendown()
            t1.right(22.5)
            t1.fd(r)
            if i==1:
                t1.goto(x,x)
                t1.goto(0,0)
                t1.right(45)
                t1.fd(r)
                t1.goto(x,x)
            elif i==2:
                t1.goto(-x,x)
                t1.goto(0, 0)
                t1.right(45)
                t1.fd(r)
                t1.goto(-x,x)
            elif i==3:
                t1.goto(-x,-x)
                t1.goto(0,0)
                t1.right(45)
                t1.fd(r)
                t1.goto(-x,-x)
            else:
                t1.goto(x,-x)
                t1.goto(0,0)
                t1.right(45)
                t1.fd(r)
                t1.goto(x,-x)
            t1.hideturtle()
    def lx(rd,l,q,j):
        def Skip(step):
            t1.pu()
            t1.fd(step)
            t1.pd()
        CLA=['yellow','#7ecff1','black']
        for a in range(l):
            t1.pu()
            t1.goto(0,0)
            t1.pendown()
            degree=-360/l*a+q
            t1.seth(degree)
            Skip(rd)
            t1.begin_fill()
            t1.fillcolor(CLA[j])
            t1.pencolor(CLA[j])
            t1.right(30)
            t1.fd(25)        
            LZ=[60,120,60]
            for i in range(3):
                t1.left(LZ[i])
                t1.fd(25)
            t1.end_fill()
        t1.hideturtle()
    def stars(m):
        CLQ=['yellow','#7ecff1']
        for i in range(m):
            a=random.uniform(-m*2,m*2)
            b=random.uniform(-m*2,m*2)
            t1.begin_fill()
            t1.penup()
            t1.goto(a,b)
            t1.pendown()
            t1.speed(900)
            t1.fillcolor(CLQ[m%2])
            t1.pencolor(CLQ[m%2])
            t1.circle(m/200)
            t1.end_fill()
            t1.hideturtle()
    '''
    初始化
    '''
    t1.setup(1.0,1.0,0,0)
    t1.bgcolor("black")
    t1.pencolor("#7ecff1")
    t1.hideturtle()
    mt=["#0489D4","#d9f1f1"]
    mv=["#6cd1ef","#d9f1f1"]
    for i in range (2):
        t1.speed(3)
        t1.delay(0)
        t1.pensize(2-i*1.2)
        t1.color(mt[i]) 
        LMX(0,-70,122.5)
        LMX(0,-100,175)
        t1.pensize(3-i*1.6)
        t1.color(mv[i]) 
        LMX(0,-200,350)
        LMX(0,-220,385)
    nc=["#94d5f0","#acdefa"]
    for i in range(2):
        t1.speed(13)
        t1.pensize(3-i*1.5)
        t1.pencolor(nc[i])
        yuan(220+i)
        yuan(250+i)
        yuan(258+i)
        t1.pensize(1)
        t1.pencolor("#389bc8")
        t1.speed(6)
        yuan(100+i)
        yuan(110+i)
        yuan(35+i)
        yuan(30+i)
    t.sleep(0.5)
    t1.speed(5)
    sixy(86,155,40)
    BT=["#54B6D8","#f0efeb"]
    t1.speed(10)
    for i in range(2):
        t1.speed(5)
        t1.delay(0)
        t1.color(BT[i])
        t1.pensize(3-i*1.6)
        t1.seth(-12)
        lbx(-123,-135.88)
        t1.seth(0)
        lbx(-90,-155.88)
        t1.seth(12)
        lbx(-57,-175.88)
    t1.speed(10)
    t1.pencolor("#5daed9")
    t1.pensize(1.3)
    ZR=[-150,30,300,120]
    for i in range(4):
        t1.seth(ZR[i])
        yue(0,53,50)
    t1.delay(0)
    t1.pu()
    t1.goto(-400, 20)
    t1.pd()
    xingzuo(235,15,0)
    for i in range(2):
        t1.pensize(10-7.7*i)
        t1.speed(12)
        t1.pu()
        t1.goto(0, -254+i*34)
        t1.pd() 
        t1.pencolor("black")
        t1.seth(0)
        t1.circle(254-i*34)
    t.sleep(2)
    t1.speed(35)
    for i in range(15):
        t1.pu()
        t1.goto(0,-240-i*4.5)
        t1.pd()
        t1.pencolor("black")
        t1.pensize(35)
        t1.seth(0)
        t1.circle(240+i*4.5)
        xingzuo(240+i*4.5,17,i)
    t.sleep(1.5)
    t1.speed(15)
    t1.pencolor("yellow")
    t1.pensize(0.7)
    xingdui(30)
    t.sleep(2)
    t1.reset()
    CL=['#7ecff1','yellow','#7ecff1','yellow']
    j=0
    for i in range(30,91,20):
        t1.delay(0)
        t1.pensize(0.1*(i-20)/10+0.7)
        t1.pencolor(CL[j])
        t1.speed(30)
        xingdui(i)
        t.sleep(1)
        j=j+1
        t1.reset()
    j=0
    t1.pencolor("yellow")
    t1.pensize(1.4)
    t1.speed(30)
    xingdui(90)
    t1.speed(50)
    t1.delay(0)
    lx(280,8,0,0)
    t.sleep(1)
    lx(340,24,0,1)
    t.sleep(1)
    lx(400,8,0,0)
    t.sleep(1.5)
    lx(280,8,0,2)
    lx(340,24,0,2)
    lx(400,8,0,2)
    t.sleep(0.75)
    for i in range(3):
        t1.speed(150+i*100)
        t1.delay(0)
        lx(380+i*150,12,0,1)
        lx(380+i*150,6,0,0)
    t1.speed(20)
    stars(51)
    stars(100)
    stars(301)
    t1.pu()
    t1.home()
    t1.pd()
    tailand(114514)
    t1.home()
    t1.pencolor('blue')
    t1.speed(100)
    t1.hideturtle()
    for i in range(92):
        t1.forward(i)
        t1.left(91)
    t1.home()
    t1.pencolor('blue')
    t1.write('修改成功',align="center",font=("宋体",20,"normal"))
    t.sleep(3)
    t1.reset()
    print('修改已完成')
    os.startfile('.\ikun\\num2.txt')
def chousile(a19198101145141):
    print('逸一时误一世，逸久逸久罢逸龄')
    print('')
    print('逸一时误一世，其意为贪逸一时则会耽误人生。')
    print('初,李天梭因昏睡而错过心爱之人——缘叶从而悔恨终生。')
    print('写完后李天梭立即愤然投入中国的革命大业之中。')
    print('')
    print('参考资料：')
    print('')
    print('《枕下夜的殷梦》记录了李天梭24岁时曾前往日本东京下北泽大学深造')
    print('并与下北泽三二党(一说池沼联盟军)领袖远野进行文化交流的过程。')
    print('书名《枕下夜的殷梦》表达想带缘叶回故乡的美好梦想。')
    print('记载了当地特色美食——面条与红茶(配方已失传)。')
    print('并详细介绍了自己与当地人缘叶相遇、相爱,终惨痛分别的故事。')
    print('其回到故乡后再次回想这段经历,泪不禁流了下来。')
    print('')
    print('(1864.5.14-1969.8.10),男')
    print('日本名田所浩(一说田所浩二),外号先辈。')
    print('名作《枕下夜的殷梦》。')
    print('清朝大臣,杰出画家,诗人,著名作家,马克思主义革命战士,革命家。')
    print('李天梭故乡殷为(今河南安阳)。')
    print('酷爱写作,嗜茶,气宇轩昂,性情豪放（指大吼大叫）。')
    print('一生创作作品70余篇(《下北泽小记》33篇载）。')
    print('但是只有几篇在《新青年》上刊登从而存活到现在。')
    print('其父母接触西洋文化故而受到了良好的教育。思想开放。')
    print('')
    print('1898年8月10日,光绪帝下谕,指责内外诸臣"墨守旧章"。')
    print('要求诸臣议论政事,不得"附会古义",不得"缘饰经术",不得"胶执成则"。')
    print('称:"朕深惟穷变通久之义,建一切,实乃苦衷。"')
    print('"倘面从心违，致失朝廷实事求是本旨，非朕所望也！"')
    print('此时,李天梭奋勇而出向光绪帝进谏,李天梭实乃戊戌六君子一般的君子啊')
    print('')
    print('在中国革命期间,其起到了决定性的作用')
    print('1942年时曾用"雪狱"逼供日军。')
    print('雪狱,将之头埋入雪中,两股挺立,同时有人撅之直至囚犯的林檎红肿为止。')
    print('有人旁观。')
    print('14天后,日军终于承受不住，将大部队8月10日进攻的消息全数招来。')
    print('有趣的是8月10日也是李天梭逝世的日子。')
    print('')
    print('其曾言道：')
    print('逸一时误一世，逸久逸久罢逸龄！')
    print('历史一课一课，亦惜一刻一刻。')
    print('先辈的这两句名言都出自《枕下夜的殷梦》')
    print('都被录入在下北泽大学大门上，是下北泽大学的校规。')
    print('')
def xiaoheizishibushixiangjinjianyu(m718327289):
    print('关于基尼肽酶的存在对人类的意义')
    print()
    print('基尼肽酶是一种由生物细胞产生的能够分解基尼肽的胞外酶,其化学本质是蛋白质。')
    print('最先由现位于下北泽孙笑川抽象大学任教的琛教授在第258号实验中发现。')
    print('人体细胞对于这种酶的制造是否对于正常人类生活尤其是唱跳rap间接产生巨大影响。')
    print()
    print('由于酶一般具有催化作用,因此研究其催化反应物与生成物对人类影响在。')
    print('探究基尼肽酶对于人类的影响的研究中有着重要的作用。')
    print('基尼肽酶参与的催化反应是将基尼肽水解产生硝黑子与各类氨基酸与水的过程。')
    print('此反应是人体唯一产生硝黑子的过程。')
    print('由此可见探究基尼肽和硝黑子对人类产生的影响是研究的关键。')
    print()
    print('由于基尼肽的独特结构。')
    print('其114及514号氨基酸极易在人体中与甲状腺素受体结合成二硫键。')
    print('使甲状腺素受体失活。但其并不会令受体细胞进行相应的生理活动。')
    print('因此甲状腺素对人体的调节作用减弱甚至消失。')
    print('因此在基尼肽酶分泌过少的人类中,会产生甲状腺素缺乏的相应症状。')
    print('若幼年期该酶分泌过少,则会引发呆小症限制其智力与身体的发育。')
    print('影响其唱跳rap篮球的能力。')
    print()
    print('另一方面,基尼肽酶分泌过多会使基尼肽短时间快速大量被水解为硝黑子。')
    print('硝黑子虽极易被人体代谢,但因结构特殊性,在人体中存在时会迅速失去电子而带上正电。')
    print('琛教授将这称之为露出基轿,露出基轿后其极易与体液中氯离子结合而被氯化。')
    print('氯化硝黑子不易代谢,多积于关节,积累过多后,会使人患氯湿寒。')
    print('限制其唱跳rap篮球的能力。')
    print()
    print('由此可见基尼肽酶对人体的重要意义。')
    print('其分泌量差异时刻影响人类生长发育。')
    print('如此重要的酶分泌过程一定有着极其繁杂的调节机制才能保证人类的正常生长生活。')
    print('可惜目前抽象生物界对于这种酶的认识尚浅,我们对于其调节过程一无所知。')
    print('另一方面不在本篇论文的探究重心，我们就不对其展开讲解目前主流的几种假说了。')
    print('')
    print('球场规则:')
    print('')
    print('1:本球场禁穿背带裤也禁止胯下运球且本球场不会有鸡,血渍与音乐')
    print('2:若听到音乐,想跳舞或发现本球场内的鸡,请离开篮球场')
    print('3:若有其他紧急事务(如触犯本规则),请告诉工作人员并将篮球交给他')
    print('4:若听到有人叫"唱跳rap""鸡你太美""你干嘛哎哟",请赶走他并离开本球场')
    print('5:若见到有梳中分或穿背带裤的人,请立刻离开')
    print('6:保持清醒认知,所有篮球都是圆形橙色的,非血红色或其他形状,无羽毛更非活物')
    print('7:若于此打篮球超过两年半,请不要在两年半内归来')
    print('8:球场外的鸡不会打篮球,若你回家途中发现打篮球的鸡,请返回寻找工作人员处理')
    print('9:工作人员不梳中分也不穿背带裤。')
    print('10:若你看见工作人员穿着背带裤或梳中分,请装作看不见,更不要将篮球交给他')
    print('11:任何情况都要相信工作人员')
    print('12:任何情况都不要发出鸡叫')
    print('本规则严格透明安全,一切都是为各位的生命危险着想,不要质疑本规则')
    print('必须准守本规则,否则后果自负。最后,祝您玩球愉快,不要用上以上规则')
    print('')
    print('潇潶仔香补香锦剑鱼')
    print('')

==> lichenggong-0.2.2.1-py3-none-any.whl: lichenggong/xiugay.py <==
def xiugay(m1919810):
    import os
    import random
    import turtle as t1
    import time as t
    import this
    for i in range(2):
        print('修改中!')
        t.sleep(1)
        print('修改中!!')
        t.sleep(1)
        print('修改中!!!')
        t.sleep(1)
    def tailand(haaasfsa):
        t1.color('red','yellow')
        t1.hideturtle()
        t1.speed(35)
        t1.goto(-100,-10)
        t1.begin_fill()
        for i in range(50):
            t1.forward(200)
            t1.left(170)
        t1.end_fill()
    def LMX(x,y,d):
        t1.penup()
        t1.goto(x, y)
        t1.pendown()
        t1.seth(60)
        for i in range(3):
            t1.fd(d)
            t1.left(120)
        t1.pu()
        t1.goto(x, -y)
        t1.pd()
        t1.seth(-60)
        for i in range(3):
            t1.fd(d)
            t1.right(120)
            t1.hideturtle()
    def yuan(r):
        t1.pu()
        t1.goto(-r*pow(3,0.5)/2, -r/2)
        t1.pd()
        t1.circle(r)
        t1.hideturtle()
    def sixy(x,y,r):
        def txyuan(x,y,r):
            t1.seth(0)
            y = y - r
            t1.pu()
            t1.goto(x, y)
            t1.pd()
            t1.pensize(2)
            t1.circle(r)
            t1.pu()
            t1.goto(x, y+3)
            t1.pd()
            r=r-3
            y=y-r
            t1.circle(r)
        t1.color("#5daed9") 
        txyuan(x,y,r)
        txyuan(-x,y,r)
        txyuan(-x,-y,r)
        txyuan(x,-y,r)
        txyuan(175,0,r)
        txyuan(-175,0,r)
        t1.hideturtle()
    def lbx(x,y):
        t1.penup()
        t1.goto(x, y)
        t1.pendown()
        for i in range(6):
            t1.fd(180)
            t1.left(60)
        t1.hideturtle()
    def yue(x,y,r):
        y=y-r
        t1.penup()
        t1.goto(x,y)
        t1.pendown() 
        t1.circle(r)
        t1.circle(r-10)
        t1.hideturtle()
    def xingzuo(r,c,h):
        t1.penup()
        t1.pencolor("#fdcfad")
        t1.goto(-10,-10)
        t1.seth(-45)
        t1.fd(r)
        t1.pendown()
        xz=['♒','♓','♈','♉','♌','♍','♎','♏','♊','♋','♐','♑']
        for i in range(12):
            t1.write(xz[(i+h)%12],font=("", c, ""))
            t1.penup()
            t1.right(90)
            t1.circle(-r, 30)
            t1.left(90)
            t1.pendown()
        t1.hideturtle()
    def xingdui(r):
        for i in range(1,5):
            te=3
            t1.penup()
            t1.goto(0, 0)
            t1.seth(i * 90)
            t1.pendown()
            t1.right(22.5)
            t1.fd(r)
            if i==1:
                t1.goto(0,3*r-te)
                t1.goto(0,0)
                t1.seth(i * 90 + 22.5)
                t1.fd(r)
                t1.goto(0,3*r-te)
            elif i==2:
                t1.goto(-3*r+te,0)
                t1.goto(0,0)
                t1.seth(i*90+22.5)
                t1.fd(r)
                t1.goto(-3*r+te,0)
            elif i==3:
                t1.goto(0,-3*r+te)
                t1.goto(0,0)
                t1.seth(i*90+22.5)
                t1.fd(r)
                t1.goto(0,-3*r+te)
            else:
                t1.goto(3*r+te,0)
                t1.goto(0,0)
                t1.seth(i*90+22.5)
                t1.fd(r)
                t1.goto(3*r+te,0)
            t1.hideturtle()
        x=pow(((2*r)**2)/2,0.5)-8
        for i in range(1,5):
            t1.pu()
            t1.goto(0, 0)
            t1.seth(i * 90)
            t1.pendown()
            t1.right(22.5)
            t1.fd(r)
            if i==1:
                t1.goto(x,x)
                t1.goto(0,0)
                t1.right(45)
                t1.fd(r)
                t1.goto(x,x)
            elif i==2:
                t1.goto(-x,x)
                t1.goto(0, 0)
                t1.right(45)
                t1.fd(r)
                t1.goto(-x,x)
            elif i==3:
                t1.goto(-x,-x)
                t1.goto(0,0)
                t1.right(45)
                t1.fd(r)
                t1.goto(-x,-x)
            else:
                t1.goto(x,-x)
                t1.goto(0,0)
                t1.right(45)
                t1.fd(r)
                t1.goto(x,-x)
            t1.hideturtle()
    def lx(rd,l,q,j):
        def Skip(step):
            t1.pu()
            t1.fd(step)
            t1.pd()
        CLA=['yellow','#7ecff1','black']
        for a in range(l):
            t1.pu()
            t1.goto(0,0)
            t1.pendown()
            degree=-360/l*a+q
            t1.seth(degree)
            Skip(rd)
            t1.begin_fill()
            t1.fillcolor(CLA[j])
            t1.pencolor(CLA[j])
            t1.right(30)
            t1.fd(25)        
            LZ=[60,120,60]
            for i in range(3):
                t1.left(LZ[i])
                t1.fd(25)
            t1.end_fill()
        t1.hideturtle()
    def stars(m):
        CLQ=['yellow','#7ecff1']
        for i in range(m):
            a=random.uniform(-m*2,m*2)
            b=random.uniform(-m*2,m*2)
            t1.begin_fill()
            t1.penup()
            t1.goto(a,b)
            t1.pendown()
            t1.speed(900)
            t1.fillcolor(CLQ[m%2])
            t1.pencolor(CLQ[m%2])
            t1.circle(m/200)
            t1.end_fill()
            t1.hideturtle()
    '''
    初始化
    '''
    t1.setup(1.0,1.0,0,0)
    t1.bgcolor("black")
    t1.pencolor("#7ecff1")
    t1.hideturtle()
    mt=["#0489D4","#d9f1f1"]
    mv=["#6cd1ef","#d9f1f1"]
    for i in range (2):
        t1.speed(3)
        t1.delay(0)
        t1.pensize(2-i*1.2)
        t1.color(mt[i]) 
        LMX(0,-70,122.5)
        LMX(0,-100,175)
        t1.pensize(3-i*1.6)
        t1.color(mv[i]) 
        LMX(0,-200,350)
        LMX(0,-220,385)
    nc=["#94d5f0","#acdefa"]
    for i in range(2):
        t1.speed(13)
        t1.pensize(3-i*1.5)
        t1.pencolor(nc[i])
        yuan(220+i)
        yuan(250+i)
        yuan(258+i)
        t1.pensize(1)
        t1.pencolor("#389bc8")
        t1.speed(6)
        yuan(100+i)
        yuan(110+i)
        yuan(35+i)
        yuan(30+i)
    t.sleep(0.5)
    t1.speed(5)
    sixy(86,155,40)
    BT=["#54B6D8","#f0efeb"]
    t1.speed(10)
    for i in range(2):
        t1.speed(5)
        t1.delay(0)
        t1.color(BT[i])
        t1.pensize(3-i*1.6)
        t1.seth(-12)
        lbx(-123,-135.88)
        t1.seth(0)
        lbx(-90,-155.88)
        t1.seth(12)
        lbx(-57,-175.88)
    t1.speed(10)
    t1.pencolor("#5daed9")
    t1.pensize(1.3)
    ZR=[-150,30,300,120]
    for i in range(4):
        t1.seth(ZR[i])
        yue(0,53,50)
    t1.delay(0)
    t1.pu()
    t1.goto(-400, 20)
    t1.pd()
    xingzuo(235,15,0)
    for i in range(2):
        t1.pensize(10-7.7*i)
        t1.speed(12)
        t1.pu()
        t1.goto(0, -254+i*34)
        t1.pd() 
        t1.pencolor("black")
        t1.seth(0)
        t1.circle(254-i*34)
    t.sleep(2)
    t1.speed(35)
    for i in range(15):
        t1.pu()
        t1.goto(0,-240-i*4.5)
        t1.pd()
        t1.pencolor("black")
        t1.pensize(35)
        t1.seth(0)
        t1.circle(240+i*4.5)
        xingzuo(240+i*4.5,17,i)
    t.sleep(1.5)
    t1.speed(15)
    t1.pencolor("yellow")
    t1.pensize(0.7)
    xingdui(30)
    t.sleep(2)
    t1.reset()
    CL=['#7ecff1','yellow','#7ecff1','yellow']
    j=0
    for i in range(30,91,20):
        t1.delay(0)
        t1.pensize(0.1*(i-20)/10+0.7)
        t1.pencolor(CL[j])
        t1.speed(30)
        xingdui(i)
        t.sleep(1)
        j=j+1
        t1.reset()
    j=0
    t1.pencolor("yellow")
    t1.pensize(1.4)
    t1.speed(30)
    xingdui(90)
    t1.speed(50)
    t1.delay(0)
    lx(280,8,0,0)
    t.sleep(1)
    lx(340,24,0,1)
    t.sleep(1)
    lx(400,8,0,0)
    t.sleep(1.5)
    lx(280,8,0,2)
    lx(340,24,0,2)
    lx(400,8,0,2)
    t.sleep(0.75)
    for i in range(3):
        t1.speed(150+i*100)
        t1.delay(0)
        lx(380+i*150,12,0,1)
        lx(380+i*150,6,0,0)
    t1.speed(20)
    stars(51)
    stars(100)
    stars(301)
    t1.pu()
    t1.home()
    t1.pd()
    tailand(114514)
    t1.home()
    t1.pencolor('blue')
    t1.speed(100)
    t1.hideturtle()
    for i in range(92):
        t1.forward(i)
        t1.left(91)
    t1.home()
    t1.pencolor('blue')
    t1.write('修改成功',align="center",font=("宋体",20,"normal"))
    t.sleep(3)
    t1.reset()
    print('修改已完成')
    os.startfile('.\ikun\\num2.txt')
def chousile(a19198101145141):
    print('逸一时误一世，逸久逸久罢逸龄')
    print('')
    print('逸一时误一世，其意为贪逸一时则会耽误人生。')
    print('初,李天梭因昏睡而错过心爱之人——缘叶从而悔恨终生。')
    print('写完后李天梭立即愤然投入中国的革命大业之中。')
    print('')
    print('参考资料：')
    print('')
    print('《枕下夜的殷梦》记录了李天梭24岁时曾前往日本东京下北泽大学深造')
    print('并与下北泽三二党(一说池沼联盟军)领袖远野进行文化交流的过程。')
    print('书名《枕下夜的殷梦》表达想带缘叶回故乡的美好梦想。')
    print('记载了当地特色美食——面条与红茶(配方已失传)。')
    print('并详细介绍了自己与当地人缘叶相遇、相爱,终惨痛分别的故事。')
    print('其回到故乡后再次回想这段经历,泪不禁流了下来。')
    print('')
    print('(1864.5.14-1969.8.10),男')
    print('日本名田所浩(一说田所浩二),外号先辈。')
    print('名作《枕下夜的殷梦》。')
    print('清朝大臣,杰出画家,诗人,著名作家,马克思主义革命战士,革命家。')
    print('李天梭故乡殷为(今河南安阳)。')
    print('酷爱写作,嗜茶,气宇轩昂,性情豪放（指大吼大叫）。')
    print('一生创作作品70余篇(《下北泽小记》33篇载）。')
    print('但是只有几篇在《新青年》上刊登从而存活到现在。')
    print('其父母接触西洋文化故而受到了良好的教育。思想开放。')
    print('')
    print('1898年8月10日,光绪帝下谕,指责内外诸臣"墨守旧章"。')
    print('要求诸臣议论政事,不得"附会古义",不得"缘饰经术",不得"胶执成则"。')
    print('称:"朕深惟穷变通久之义,建一切,实乃苦衷。"')
    print('"倘面从心违，致失朝廷实事求是本旨，非朕所望也！"')
    print('此时,李天梭奋勇而出向光绪帝进谏,李天梭实乃戊戌六君子一般的君子啊')
    print('')
    print('在中国革命期间,其起到了决定性的作用')
    print('1942年时曾用"雪狱"逼供日军。')
    print('雪狱,将之头埋入雪中,两股挺立,同时有人撅之直至囚犯的林檎红肿为止。')
    print('当日军脱出时有人旁观。')
    print('1.919天后,日军终于承受不住，将大部队8月10日进攻的消息全数招来。')
    print('有趣的是8月10日也是李天梭逝世的日子。')
    print('')
    print('其曾言道：')
    print('逸一时误一世，逸久逸久罢逸龄！')
    print('历史一课一课，亦惜一刻一刻。')
    print('先辈的这两句名言都出自《枕下夜的殷梦》')
    print('都被录入在下北泽大学大门上，是下北泽大学的校规。')
    print('')
def xiaoheizishibushixiangjinjianyu(m718327289):
    print('关于基尼肽酶的存在对人类的意义')
    print()
    print('基尼肽酶是一种由生物细胞产生的能够分解基尼肽的胞外酶,其化学本质是蛋白质。')
    print('最先由现位于下北泽孙笑川抽象大学任教的杰教授在第258号实验中发现。')
    print('人体细胞对于这种酶的制造是否对于正常人类生活尤其是唱跳rap间接产生巨大影响。')
    print()
    print('由于酶一般具有催化作用,因此研究其催化反应物与生成物对人类影响在。')
    print('探究基尼肽酶对于人类的影响的研究中有着重要的作用。')
    print('基尼肽酶参与的催化反应是将基尼肽水解产生硝黑子与各类氨基酸与水的过程。')
    print('此反应是人体唯一产生硝黑子的过程。')
    print('由此可见探究基尼肽和硝黑子对人类产生的影响是研究的关键。')
    print()
    print('由于基尼肽的独特结构。')
    print('其114及514号氨基酸极易在人体中与甲状腺素受体结合成二硫键。')
    print('使甲状腺素受体失活。但其并不会令受体细胞进行相应的生理活动。')
    print('因此甲状腺素对人体的调节作用减弱甚至消失。')
    print('因此在基尼肽酶分泌过少的人类中,会产生甲状腺素缺乏的相应症状。')
    print('若幼年期该酶分泌过少,则会引发呆小症限制其智力与身体的发育。')
    print('影响其唱跳rap篮球的能力。')
    print()
    print('另一方面,基尼肽酶分泌过多会使基尼肽短时间快速大量被水解为硝黑子。')
    print('硝黑子虽极易被人体代谢,但因结构特殊性,在人体中存在时会迅速失去电子而带上正电。')
    print('杰教授将这称之为露出基轿,露出基轿后其极易与体液中氯离子结合而被氯化。')
    print('氯化硝黑子不易代谢,多积于关节,积累过多后,会使人患氯湿寒。')
    print('限制其唱跳rap篮球的能力。')
    print()
    print('由此可见基尼肽酶对人体的重要意义。')
    print('其分泌量差异时刻影响人类生长发育。')
    print('如此重要的酶分泌过程一定有着极其繁杂的调节机制才能保证人类的正常生长生活。')
    print('可惜目前抽象生物界对于这种酶的认识尚浅,我们对于其调节过程一无所知。')
    print('另一方面不在本篇论文的探究重心，我们就不对其展开讲解目前主流的几种假说了。')
    print('')
    print('球场规则:')
    print('')
    print('1:本球场禁穿背带裤也禁止胯下运球且本球场不会有鸡,血渍与音乐')
    print('2:若听到音乐,想跳舞或发现本球场内的鸡,请离开篮球场')
    print('3:若有其他紧急事务(如触犯本规则),请告诉工作人员并将篮球交给他')
    print('4:若听到有人叫"唱跳rap""鸡你太美""你干嘛哎哟",请赶走他并离开本球场')
    print('5:若见到有梳中分或穿背带裤的人,请立刻离开')
    print('6:保持清醒认知,所有篮球都是圆形橙色的,非血红色或其他形状,无羽毛更非活物')
    print('7:若于此打篮球超过两年半,请不要在两年半内归来')
    print('8:球场外的鸡不会打篮球,若你回家途中发现打篮球的鸡,请返回寻找工作人员处理')
    print('9:工作人员不梳中分也不穿背带裤。')
    print('10:若你看见工作人员穿着背带裤或梳中分,请装作看不见,更不要将篮球交给他')
    print('11:任何情况都要相信工作人员')
    print('12:任何情况都不要发出鸡叫')
    print('本规则严格透明安全,一切都是为各位的生命危险着想,不要质疑本规则')
    print('必须准守本规则,否则后果自负。最后,祝您玩球愉快,不要用上以上规则')
    print('')
    print('潇潶仔香补香锦剑鱼')
    print('')
